#ifndef _I2CMASTER_UART2I2C_H_
#define _I2CMASTER_UART2I2C_H_

#define UART2I2C_SLAVE_ADDRESS 0x7F

#define UART2I2C_RXFIFO_DATA (0)
#define UART2I2C_TXFIFO_DATA (1)
#define UART2I2C_RXFIFO_STATUS (2)
#define UART2I2C_TXFIFO_STATUS (3)
#define UART2I2C_RXFIFO_CMD (4)
#define UART2I2C_TXFIFO_CMD (5)
#define UART2I2C_UBRR (6)
#define UART2I2C_UCSR (8)
#define UART2I2C_STATUS_CONTROL (9)
#define UART2I2C_RXCHARS (10)
#define UART2I2C_TXCHARS (12)

#define UART2I2C_ACCELX_FIFO_DATA (20)
#define UART2I2C_ACCELY_FIFO_DATA (22)
#define UART2I2C_ACCELX_WORDS (24)
#define UART2I2C_ACCELY_WORDS (26)
#define UART2I2C_ACCEL_INTERVAL (28)

#define UART2I2C_FIRMWARE_VERSION (40)
#define UART2I2C_FIRMWARE_VERSION_SIZE (8)

#define UART2I2C_GPS (64)
#define RESERVE (1)
#define UART2I2C_GPS_UTC_TIME (UART2I2C_GPS)
#define UART2I2C_GPS_UTC_TIME_SIZE (10+RESERVE)

#define UART2I2C_GPS_LATITUDE (UART2I2C_GPS_UTC_TIME+UART2I2C_GPS_UTC_TIME_SIZE)
#define UART2I2C_GPS_LATITUDE_SIZE (10+RESERVE)

#define UART2I2C_GPS_LATITUDE_H (UART2I2C_GPS_LATITUDE+UART2I2C_GPS_LATITUDE_SIZE)
#define UART2I2C_GPS_LATITUDE_H_SIZE (2+RESERVE)

#define UART2I2C_GPS_LONGITUDE (UART2I2C_GPS_LATITUDE_H+UART2I2C_GPS_LATITUDE_H_SIZE)
#define UART2I2C_GPS_LONGITUDE_SIZE (10+RESERVE)

#define UART2I2C_GPS_LONGITUDE_H (UART2I2C_GPS_LONGITUDE+UART2I2C_GPS_LONGITUDE_SIZE)
#define UART2I2C_GPS_LONGITUDE_H_SIZE (2+RESERVE)

#define UART2I2C_GPS_SATELLITES (UART2I2C_GPS_LONGITUDE_H+UART2I2C_GPS_LONGITUDE_H_SIZE)
#define UART2I2C_GPS_SATELLITES_SIZE (3+RESERVE)

#define UART2I2C_GPS_ALTITUDE (UART2I2C_GPS_SATELLITES+UART2I2C_GPS_SATELLITES_SIZE)
#define UART2I2C_GPS_ALTITUDE_SIZE (8+RESERVE)

#define UART2I2C_GPS_COURSE (UART2I2C_GPS_ALTITUDE+UART2I2C_GPS_ALTITUDE_SIZE)
#define UART2I2C_GPS_COURSE_SIZE (6+RESERVE)

#define UART2I2C_GPS_SPEED (UART2I2C_GPS_COURSE+UART2I2C_GPS_COURSE_SIZE)
#define UART2I2C_GPS_SPEED_SIZE (7+RESERVE)

#define UART2I2C_GPS_DATE (UART2I2C_GPS_SPEED+UART2I2C_GPS_SPEED_SIZE)
#define UART2I2C_GPS_DATE_SIZE (7+RESERVE)

#define UART2I2C_GPS_STRUCT_SIZE (UART2I2C_GPS_DATE+UART2I2C_GPS_DATE_SIZE-UART2I2C_GPS)
#define UART2I2C_ID (255)

#define UART2I2C_STATUS_CONTROL_PARSER_ENABLED (0x01)
#define UART2I2C_STATUS_CONTROL_CLEAR_GPS_DATA (0x02)

typedef struct
{
  u8 utcTime[UART2I2C_GPS_UTC_TIME_SIZE];
  u8 latitude[UART2I2C_GPS_LATITUDE_SIZE];
  u8 latitudeH[UART2I2C_GPS_LATITUDE_H_SIZE];
  u8 longitude[UART2I2C_GPS_LONGITUDE_SIZE];
  u8 longitudeH[UART2I2C_GPS_LONGITUDE_H_SIZE];
  u8 satellites[UART2I2C_GPS_SATELLITES_SIZE];
  u8 altitude[UART2I2C_GPS_ALTITUDE_SIZE];
  u8 course[UART2I2C_GPS_COURSE_SIZE];
  u8 speed[UART2I2C_GPS_SPEED_SIZE];
  u8 date[UART2I2C_GPS_DATE_SIZE];
} gpsDataStruct;

void init_uart2i2c (u8 myslaveaddr);

u8 uart2i2c_tx_data (u8 * data, u8 len);
u8 uart2i2c_rx_data (u8 * data, u8 len);

u8 uart2i2c_select_reg (u8 reg);

u8 uart2i2c_read_rxfifo_data (u8 * outbuf, u8 len);
u8 uart2i2c_write_txfifo_data (u8 * inbuf, u8 len);

u8 uart2i2c_read_rxfifo_status (u8 * val);
u8 uart2i2c_read_txfifo_status (u8 * val);

u8 uart2i2c_read_rxfifo_cmd (u8 * val);
u8 uart2i2c_write_rxfifo_cmd (u8 val);
u8 uart2i2c_read_txfifo_cmd (u8 * val);
u8 uart2i2c_write_txfifo_cmd (u8 val);

u8 uart2i2c_read_ubrr (u16 * val);
u8 uart2i2c_write_ubrr (u16 val);

u8 uart2i2c_read_ucsr (u8 * val);
u8 uart2i2c_write_ucsr (u8 val);

u8 uart2i2c_read_control (u8 * val);
u8 uart2i2c_write_control (u8 val);

u8 uart2i2c_read_interval (u8 * val);
u8 uart2i2c_write_interval (u8 val);

u8 uart2i2c_read_rxchars (u16 * val);
u8 uart2i2c_read_txchars (u16 * val);

u8 uart2i2c_read_id (u8 * val);

u8 uart2i2c_read_gps_data (u8 offs, u8 * val);

u8 uart2i2c_read_accelx_fifo_data (u16 * outbuf, u8 len);
u8 uart2i2c_read_accely_fifo_data (u16 * outbuf, u8 len);
u8 uart2i2c_read_accelx_words (u8 * val);
u8 uart2i2c_read_accely_words (u8 * val);

u8 uart2i2c_read_baby_fw_version (u8 * outbuf, u8 len);

#endif
